summaryrefslogtreecommitdiff
path: root/indra/newview/lltwitterconnect.cpp
diff options
context:
space:
mode:
authorCho <cho@lindenlab.com>2013-11-06 02:06:53 +0000
committerCho <cho@lindenlab.com>2013-11-06 02:06:53 +0000
commit1a1826a4f7110dc2b7859f6ce871ab0ac957525f (patch)
treeb2410137e3d31217cc268e555db8de2f06a4ea82 /indra/newview/lltwitterconnect.cpp
parent181a7d22964b7cfbdd108493560ea60064a65f86 (diff)
separated web floaters for Facebook, Flickr, and Twitter to fix ACME-1151
Diffstat (limited to 'indra/newview/lltwitterconnect.cpp')
-rw-r--r--indra/newview/lltwitterconnect.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/lltwitterconnect.cpp b/indra/newview/lltwitterconnect.cpp
index 5abd654d0c..fe45d3e4d0 100644
--- a/indra/newview/lltwitterconnect.cpp
+++ b/indra/newview/lltwitterconnect.cpp
@@ -280,11 +280,11 @@ void LLTwitterConnect::openTwitterWeb(std::string url)
p.url(url).allow_address_entry(false);
p.url(url).allow_back_forward_navigation(false);
p.url(url).trusted_content(true);
- LLFloater *floater = LLFloaterReg::showInstance("fbc_web", p);
+ LLFloater *floater = LLFloaterReg::showInstance("twitter_web", p);
//the internal web browser has a bug that prevents it from gaining focus unless a mouse event occurs first (it seems).
//So when showing the internal web browser, set focus to it's containing floater "fbc_web". When a mouse event
//occurs on the "webbrowser" panel part of the floater, a mouse cursor will properly show and the "webbrowser" will gain focus.
//fbc_web floater contains the "webbrowser" panel. JIRA: ACME-744
gFocusMgr.setKeyboardFocus( floater );
//LLUrlAction::openURLExternal(url);
@@ -280,11 +280,11 @@ void LLTwitterConnect::openTwitterWeb(std::string url)
//the internal web browser has a bug that prevents it from gaining focus unless a mouse event occurs first (it seems).
- //So when showing the internal web browser, set focus to it's containing floater "fbc_web". When a mouse event
+ //So when showing the internal web browser, set focus to it's containing floater "twitter_web". When a mouse event
//occurs on the "webbrowser" panel part of the floater, a mouse cursor will properly show and the "webbrowser" will gain focus.
@@ -280,11 +280,11 @@ void LLTwitterConnect::openTwitterWeb(std::string url)
//occurs on the "webbrowser" panel part of the floater, a mouse cursor will properly show and the "webbrowser" will gain focus.
- //fbc_web floater contains the "webbrowser" panel. JIRA: ACME-744
+ //twitter_web floater contains the "webbrowser" panel. JIRA: ACME-744
gFocusMgr.setKeyboardFocus( floater );
//LLUrlAction::openURLExternal(url);